# Generated by Django 5.1.6 on 2025-08-12 03:15

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("drfchelseru", "0002_otpcode_session_user"),
    ]

    operations = [
        migrations.RenameField(
            model_name="otpcode",
            old_name="mobile",
            new_name="mobile_number",
        ),
    ]
