# Generated by Django 5.1.6 on 2025-08-12 01:59

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="Message",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("message_text", models.TextField()),
                ("mobile_number", models.CharField(max_length=20)),
                ("_from", models.CharField(blank=True, max_length=20, null=True)),
                ("status", models.CharField(blank=True, max_length=20, null=True)),
                ("updated_at", models.DateTimeField(auto_now=True)),
                ("created_at", models.DateTimeField(auto_now_add=True)),
            ],
        ),
    ]
