# Generated by Django 5.1.6 on 2025-08-26 19:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('drfchelseru', '0012_payment'),
    ]

    operations = [
        migrations.AddField(
            model_name='payment',
            name='authority',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='payment',
            name='data',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='payment',
            name='status_code',
            field=models.IntegerField(blank=True, null=True),
        ),
    ]
